==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Test/Gui/Resources/translations/Test_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD unittest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Mislukkingen en fouten</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Omschrijving</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Start</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Help</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Over</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Sluiten</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Inactief</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Voortgang</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Resterend:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Fouten:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Mislukkingen:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Uitvoeren:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Selecteer Testnaam:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Help</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Over FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD unittest is onderdeel van FreeCAD en ondersteunt het schrijven van unit tests voor eigen modules.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Voer de naam in van het oproepbare object welke, indien opgeroepen, een TestCase zal teruggeven. Druk op 'start', en de aldus geproduceerde test zal worden uitgevoerd.
Dubbel klik op een fout in de boomstructuur om meer informatie te zien, inclusief de stack trace.</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Test/Gui/Resources/translations/Test_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD unittest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Mislukkingen en fouten</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Omschrijving</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Start</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Help</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Over</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Sluiten</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Inactief</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Vooruitgang</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Resterend:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Fouten:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Mislukkingen:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Uitvoeren:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Selecteer testnaam:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Help</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Over FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD unittest is onderdeel van FreeCAD en ondersteunt het schrijven van unit tests voor eigen modules.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Voer de naam in van het oproepbare object welke, indien opgeroepen, een TestCase zal teruggeven. Druk op 'start', en de aldus geproduceerde test zal worden uitgevoerd.
Dubbel klik op een fout in de boomstructuur om meer informatie te zien, inclusief de stack trace.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Voer de naam in van een opvraagbaar object dat, wanneer het wordt opgeroepen, een TestCase retourneert.
Klik op 'start' en de aldus geproduceerde test wordt uitgevoerd.

Dubbelklik op een fout in de structuurweergave om meer informatie erover te zien, inclusief de stacktracering.</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest is onderdeel van FreeCAD en ondersteunt het schrijven van eenheidstests voor de eigen modules.</translation>
    </message>
  </context>
</TS>
